==> rn-hidoop-ui-lib-0.1.11.tgz: package/src/Components/Molecules/Card/StoreProduct.js <==
import React from 'react';
import { Image, StyleSheet, TouchableOpacity, View } from 'react-native';
import { colors, width } from '../../../constant/theme';
import { Text } from '../../Atoms';
import { GhostButton } from '../Button';

const StoreProduct = ({ data = {}, onCardPress, onActionPress, style }) => {
  return (
    <TouchableOpacity
      onPress={onCardPress}
      key={data?.id?.toString()}
      style={[styles.cardWrapper, style]}
    >
      <View style={styles.imageWrapper}>
        <Image
          source={{ uri: data?.image_url }}
          style={styles.imageThumbnail}
          resizeMethod="auto"
          resizeMode="cover"
        />
      </View>
      <View style={{ padding: width * 0.03 }}>
        <Text
          text={data?.item_name}
          variant="light"
          size={'large'}
          color={colors.grey.grey8}
          numberOfLines={2}
          textStyle={{ marginBottom: 10 }}
        />
        <Text text={data?.price} variant="bold" />
        <GhostButton
          onPress={onActionPress}
          title={'Tambah'}
          style={{ marginTop: width * 0.05 }}
        />
      </View>
    </TouchableOpacity>
  );
};

const styles = StyleSheet.create({
  cardWrapper: {
    backgroundColor: 'white',
    width: '43%',
    borderRadius: 20,
    margin: width * 0.03,
    borderWidth: 0.5,
    borderColor: colors.grey.grey3,
  },
  imageWrapper: {
    width: '100%',
    aspectRatio: 1,
    marginBottom: width * 0.03,
  },
  imageThumbnail: {
    width: '100%',
    height: '100%',
    aspectRatio: 1,
    borderRadius: 20,
    borderBottomRightRadius: 0,
    borderBottomLeftRadius: 0,
  },
});

export default StoreProduct;

==> rn-hidoop-ui-lib-0.1.12.tgz: package/src/Components/Molecules/Card/StoreProduct.js <==
import React from 'react';
import { Image, StyleSheet, TouchableOpacity, View } from 'react-native';
import { colors, width } from '../../../constant/theme';
import { Text } from '../../Atoms';
import { GhostButton } from '../Button';

const StoreProduct = ({
  data = {},
  onCardPress,
  emptyStock,
  onActionPress,
  style,
}) => {
  return (
    <TouchableOpacity
      onPress={onCardPress}
      key={data?.id?.toString()}
      style={[styles.cardWrapper, style]}
    >
      <View style={styles.imageWrapper}>
        <Image
          source={{ uri: data?.image_url }}
          style={styles.imageThumbnail}
          resizeMethod="auto"
          resizeMode="cover"
        />
      </View>
      <View style={{ padding: width * 0.03 }}>
        <Text
          text={data?.item_name}
          variant="light"
          size={'large'}
          color={colors.grey.grey8}
          numberOfLines={2}
          textStyle={{ marginBottom: 10 }}
        />
        <Text text={data?.price} variant="bold" />
        {emptyStock ? (
          <Text
            text="Stok Habis"
            color={colors.error}
            textStyle={{ marginTop: width * 0.03 }}
          />
        ) : (
          <GhostButton
            onPress={onActionPress}
            title={'Tambah'}
            style={{ marginTop: width * 0.05 }}
          />
        )}
      </View>
    </TouchableOpacity>
  );
};

const styles = StyleSheet.create({
  cardWrapper: {
    backgroundColor: 'white',
    width: '43%',
    borderRadius: 20,
    margin: width * 0.03,
    borderWidth: 0.5,
    borderColor: colors.grey.grey3,
  },
  imageWrapper: {
    width: '100%',
    aspectRatio: 1,
    marginBottom: width * 0.03,
  },
  imageThumbnail: {
    width: '100%',
    height: '100%',
    aspectRatio: 1,
    borderRadius: 20,
    borderBottomRightRadius: 0,
    borderBottomLeftRadius: 0,
  },
});

export default StoreProduct;
